==> cutty-0.12.0-py3-none-any.whl: cutty/entrypoints/cli/link.py <==
"""Command-line interface for linking projects to a Cookiecutter template."""
import pathlib
from typing import Optional

import click

from cutty.entrypoints.cli.create import extra_context_callback
from cutty.services.link import link as service_link
from cutty.templates.domain.bindings import Binding


@click.argument("template", required=False)
@click.argument("extra-context", nargs=-1, callback=extra_context_callback)
@click.option(
    "--no-input",
    is_flag=True,
    default=False,
    help="Do not prompt for template variables.",
)
@click.option(
    "-C",
    "--cwd",
    metavar="DIR",
    type=click.Path(
        exists=True, file_okay=False, dir_okay=True, path_type=pathlib.Path
    ),
    help="Directory of the generated project.",
)
@click.option(
    "-c",
    "--checkout",
    metavar="REV",
    help="Branch, tag, or commit hash of the template repository.",
)
@click.option(
    "--directory",
    metavar="DIR",
    type=click.Path(path_type=pathlib.Path),
    help=(
        "Directory within the template repository that contains the "
        "cookiecutter.json file."
    ),
)
def link(
    template: Optional[str],
    extra_context: dict[str, str],
    no_input: bool,
    cwd: Optional[pathlib.Path],
    checkout: Optional[str],
    directory: Optional[pathlib.Path],
) -> None:
    """Link project to a Cookiecutter template."""
    extrabindings = [Binding(key, value) for key, value in extra_context.items()]
    service_link(
        template,
        extrabindings=extrabindings,
        no_input=no_input,
        projectdir=cwd,
        checkout=checkout,
        directory=pathlib.PurePosixPath(directory) if directory is not None else None,
    )

==> cutty-0.14.0-py3-none-any.whl: cutty/entrypoints/cli/link.py <==
"""Command-line interface for linking projects to a Cookiecutter template."""
import pathlib
from typing import Optional

import click

from cutty.entrypoints.cli.cookiecutter import extra_context_callback
from cutty.services.link import link as service_link
from cutty.templates.domain.bindings import Binding


@click.argument("template", required=False)
@click.argument("extra-context", nargs=-1, callback=extra_context_callback)
@click.option(
    "--non-interactive",
    is_flag=True,
    default=False,
    help="Do not prompt for template variables.",
)
@click.option(
    "-C",
    "--cwd",
    metavar="DIR",
    type=click.Path(
        exists=True, file_okay=False, dir_okay=True, path_type=pathlib.Path
    ),
    help="Directory of the generated project.",
)
@click.option(
    "--revision",
    metavar="REV",
    help="Branch, tag, or commit hash of the template repository.",
)
@click.option(
    "--template-directory",
    metavar="DIR",
    type=click.Path(path_type=pathlib.Path),
    help=(
        "Directory within the template repository that contains the "
        "cookiecutter.json file."
    ),
)
def link(
    template: Optional[str],
    extra_context: dict[str, str],
    non_interactive: bool,
    cwd: Optional[pathlib.Path],
    revision: Optional[str],
    template_directory: Optional[pathlib.Path],
) -> None:
    """Link project to a Cookiecutter template."""
    if cwd is None:
        cwd = pathlib.Path.cwd()

    extrabindings = [Binding(key, value) for key, value in extra_context.items()]

    service_link(
        template,
        cwd,
        extrabindings=extrabindings,
        interactive=not non_interactive,
        revision=revision,
        directory=template_directory,
    )
